import { ChangeDetectorRef, Component } from '@angular/core';
import { AppraisalSubordinateModel, MyAppraisalSubordinateModel } from 'src/app/shared/model/appraisal-subordinate.model';
import { AppraisalService } from 'src/app/shared/services/appraisal.service';

@Component({
  selector: 'app-supervisor-evaluation',
  templateUrl: './supervisor-evaluation.component.html',
  styleUrls: ['./supervisor-evaluation.component.scss']
})
export class SupervisorEvaluationComponent {
  pathTitle = ['การประเมินผล', 'ประเมินโดยหัวหน้า']
  pageEvalution = ''
  currentDate = new Date()
  subordinate: { loading: false, select: AppraisalSubordinateModel, dataList: AppraisalSubordinateModel[], dataListRound: AppraisalSubordinateModel[][] } = { loading: false, select: new MyAppraisalSubordinateModel(), dataListRound: [], dataList: [] }
  search = ""
  currentPage = 1
  page = Array.from({ length: 1 }, (_, i) => i + 1)

  evaluateeId = ""
  evaluaterId = ""
  competencyTypeId = ""
  evaluationRoundId = ""
  constructor(private appraisalService: AppraisalService,
    private cdr: ChangeDetectorRef) {
  }
  ngOnInit(): void {
    this.evaluaterId = this.decodeJWT(sessionStorage.getItem("accessToken") || '').employeeid
    this.getBossList()
  }
  getBossList() {
    this.appraisalService.getBossList().subscribe({
      next: response => {
        this.subordinate.dataListRound = [response.map(x => new MyAppraisalSubordinateModel(x))]
        this.subordinate.dataList = this.subordinate.dataListRound.map(x => x.map(y => new MyAppraisalSubordinateModel(y)))?.[0] || []
        this.searchChange()
        this.cdr.detectChanges()
      }, error: error => {
        this.cdr.detectChanges()
      }
    })
  }
  subordinateFilter() {
    return this.subordinate.dataList.filter(x => {
      return x.apsassessy.employeeId.toLowerCase().includes(this.search.toLowerCase()) || x.apsassessy.thFullName.toLowerCase().includes(this.search.toLowerCase())
    })
  }
  searchChange() {
    this.currentPage = 1
    this.page = Array.from({ length: Math.ceil(this.subordinateFilter().length / 10) }, (_, i) => i + 1);
  }
  selectSubordinate(data: AppraisalSubordinateModel, competencyTypeId: string, evaluationRoundId: string) {
    this.subordinate.select = new MyAppraisalSubordinateModel(data)

    this.evaluateeId = this.subordinate.select.apsassessy.employeeId
    this.competencyTypeId = competencyTypeId
    this.evaluationRoundId = evaluationRoundId
    this.cdr.detectChanges()
  }
  selectDataListRound(data: AppraisalSubordinateModel[]) {
    this.subordinate.dataList = data.map(x => new MyAppraisalSubordinateModel(x))
    this.searchChange()
    this.cdr.detectChanges()
  }

  decodeJWT(token: string) {
    let base64Url = token.split('.')[1]; // ดึงส่วนที่เป็น Payload
    let base64 = base64Url.replace('-', '+').replace('_', '/'); // แก้ไข base64 ให้ถูกต้อง
    let jsonPayload = decodeURIComponent(atob(base64).split('').map(function (c) {
      return '%' + ('00' + c.charCodeAt(0).toString(16)).slice(-2);
    }).join(''));
    return JSON.parse(jsonPayload);
  }
}
